@@ -15,59 +15,58 @@ build_time_vars = {'ABIFLAGS': '',
  'BINDIR': '/usr/pkg/bin',
  'BINLIBDEST': '/usr/pkg/lib/python3.11',
  'BLDLIBRARY': '-L. -lpython3.11',
- 'BLDSHARED': 'gcc -pthread -shared -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
-              '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
-              '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
-              '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+ 'BLDSHARED': 'gcc -pthread -shared -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib '
+              '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
+              '-Wl,-R/usr/X11R7/lib -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib '
+              '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
+              '-Wl,-R/usr/X11R7/lib',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'm68k--netbsdelf',
+ 'BUILD_GNU_TYPE': 'powerpc--netbsd',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wsign-compare -DNDEBUG -O2 -fno-reorder-blocks -I/usr/include '
-           '-I/usr/pkg/include -O2 -fno-reorder-blocks -I/usr/include '
-           '-I/usr/pkg/include -O2 -fno-reorder-blocks -I/usr/include '
+ 'CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include -I/usr/pkg/include -O2 '
+           '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
            '-I/usr/pkg/include',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -fno-reorder-blocks -I/usr/include '
-                     '-I/usr/pkg/include',
+ 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/pkg/include',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include',
- 'CONFIGURE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+ 'CONFIGURE_LDFLAGS': '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                       '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
                       '-Wl,-R/usr/X11R7/lib',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIGURE_LDFLAGS_NOLTO': '',
- 'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-expat' "
+ 'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' "
+                "'--with-readline=readline' '--with-system-expat' "
                 "'--with-system-ffi' '--without-ensurepip' "
                 "'--without-pymalloc' '--prefix=/usr/pkg' "
-                "'--build=m68k--netbsdelf' '--host=m68k--netbsdelf' "
+                "'--build=powerpc--netbsd' '--host=powerpc--netbsd' "
                 "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
-                "'build_alias=m68k--netbsdelf' 'host_alias=m68k--netbsdelf' "
-                "'PKG_CONFIG=/tmp/pkgbuild/lang/python311/work.m68k/.tools/bin/pkg-config' "
+                "'build_alias=powerpc--netbsd' 'host_alias=powerpc--netbsd' "
+                "'PKG_CONFIG=/usr/pkgsrc/lang/python311/work/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python311/work.m68k/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python311/work.m68k/.buildlink/share/pkgconfig' "
-                "'CC=gcc' 'CFLAGS=-O2 -fno-reorder-blocks -I/usr/include "
-                "-I/usr/pkg/include' 'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib "
-                '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-                "-Wl,-R/usr/X11R7/lib' 'LIBS=' 'CPPFLAGS=-I/usr/include "
-                "-I/usr/pkg/include'",
+                "'PKG_CONFIG_LIBDIR=/usr/pkgsrc/lang/python311/work/.buildlink/lib/pkgconfig:/usr/pkgsrc/lang/python311/work/.buildlink/share/pkgconfig' "
+                "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/pkg/include' "
+                "'LDFLAGS=-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
+                "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
+                "'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python311/work.m68k/Python-3.11.7/coverage.info',
+ 'COVERAGE_INFO': '/usr/pkgsrc/lang/python311/work/Python-3.11.8/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python311/work.m68k/Python-3.11.7/lcov-report',
+ 'COVERAGE_REPORT': '/usr/pkgsrc/lang/python311/work/Python-3.11.8/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
@@ -246,7 +245,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_FUTIMES': 1,
  'HAVE_FUTIMESAT': 0,
  'HAVE_GAI_STRERROR': 1,
- 'HAVE_GCC_ASM_FOR_MC68881': 1,
+ 'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
  'HAVE_GCC_UINT128_T': 0,
@@ -607,7 +606,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
- 'HOST_GNU_TYPE': 'm68k--netbsdelf',
+ 'HOST_GNU_TYPE': 'powerpc--netbsd',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
                    '/usr/pkg/include/python3.11 /usr/pkg/include/python3.11',
  'INCLUDEDIR': '/usr/pkg/include',
@@ -621,26 +620,26 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared',
- 'LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
-            '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib -L/usr/lib -Wl,-R/usr/lib '
-            '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-            '-Wl,-R/usr/X11R7/lib',
+ 'LDFLAGS': '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+            '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
+            '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+            '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.11.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
-             '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
-             '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
-             '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+ 'LDSHARED': 'gcc -pthread -shared -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib '
+             '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
+             '-Wl,-R/usr/X11R7/lib -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib '
+             '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
+             '-Wl,-R/usr/X11R7/lib',
  'LDVERSION': '3.11',
  'LIBC': '',
  'LIBDEST': '/usr/pkg/lib/python3.11',
  'LIBDIR': '/usr/pkg/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -fno-reorder-blocks '
-                    '-I/usr/include -I/usr/pkg/include -O2 -fno-reorder-blocks '
-                    '-I/usr/include -I/usr/pkg/include -O2 -fno-reorder-blocks '
-                    '-I/usr/include -I/usr/pkg/include -std=gnu11 -Wextra '
+ 'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
+                    '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                    '-O2 -I/usr/include -I/usr/pkg/include -std=gnu11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
@@ -652,10 +651,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1 '
-                    '-Wsign-compare -DNDEBUG -O2 -fno-reorder-blocks '
-                    '-I/usr/include -I/usr/pkg/include -O2 -fno-reorder-blocks '
-                    '-I/usr/include -I/usr/pkg/include -O2 -fno-reorder-blocks '
-                    '-I/usr/include -I/usr/pkg/include -std=gnu11 -Wextra '
+                    '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
+                    '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                    '-O2 -I/usr/include -I/usr/pkg/include -std=gnu11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
@@ -909,7 +907,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '-L/usr/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
- 'OPT': '-DNDEBUG -O2 -fno-reorder-blocks -I/usr/include -I/usr/pkg/include',
+ 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/pkg/include',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -945,12 +943,11 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -fno-reorder-blocks '
-                             '-I/usr/include -I/usr/pkg/include -O2 '
-                             '-fno-reorder-blocks -I/usr/include '
-                             '-I/usr/pkg/include -O2 -fno-reorder-blocks '
-                             '-I/usr/include -I/usr/pkg/include -std=gnu11 '
-                             '-Wextra -Wno-unused-parameter '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
+                             '-I/usr/pkg/include -O2 -I/usr/include '
+                             '-I/usr/pkg/include -O2 -I/usr/include '
+                             '-I/usr/pkg/include -std=gnu11 -Wextra '
+                             '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
@@ -958,49 +955,46 @@ build_time_vars = {'ABIFLAGS': '',
                              '-I./Include -I/usr/include -I/usr/pkg/include '
                              '-I/usr/include -I/usr/pkg/include -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -fno-reorder-blocks -I/usr/include '
-              '-I/usr/pkg/include -O2 -fno-reorder-blocks -I/usr/include '
-              '-I/usr/pkg/include -O2 -fno-reorder-blocks -I/usr/include '
+ 'PY_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include -I/usr/pkg/include '
+              '-O2 -I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
               '-I/usr/pkg/include',
  'PY_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                      '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -fno-reorder-blocks '
-                   '-I/usr/include -I/usr/pkg/include -O2 -fno-reorder-blocks '
-                   '-I/usr/include -I/usr/pkg/include -O2 -fno-reorder-blocks '
-                   '-I/usr/include -I/usr/pkg/include -std=gnu11 -Wextra '
+ 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
+                   '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                   '-O2 -I/usr/include -I/usr/pkg/include -std=gnu11 -Wextra '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                    '-I/usr/include -I/usr/pkg/include -I/usr/include '
                    '-I/usr/pkg/include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+ 'PY_CORE_LDFLAGS': '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
-                    '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+                    '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
                 '-I/usr/include -I/usr/pkg/include',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
-               '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib -L/usr/lib '
-               '-Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
-               '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+ 'PY_LDFLAGS': '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+               '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
+               '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+               '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'PY_LDFLAGS_NODIST': '',
- 'PY_LDFLAGS_NOLTO': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+ 'PY_LDFLAGS_NOLTO': '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                      '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
-                     '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+                     '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                      '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 0,
  'PY_SQLITE_HAVE_SERIALIZE': 0,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -fno-reorder-blocks '
-                        '-I/usr/include -I/usr/pkg/include -O2 '
-                        '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include '
-                        '-O2 -fno-reorder-blocks -I/usr/include '
+ 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
+                        '-I/usr/pkg/include -O2 -I/usr/include '
+                        '-I/usr/pkg/include -O2 -I/usr/include '
                         '-I/usr/pkg/include -std=gnu11 -Wextra '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wstrict-prototypes '
@@ -1019,7 +1013,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python311/work.m68k/Python-3.11.7',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python311/work/Python-3.11.8',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SHELL': '/bin/sh',
@@ -1032,7 +1026,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FPOS_T': 264,
  'SIZEOF_INT': 4,
  'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 12,
+ 'SIZEOF_LONG_DOUBLE': 8,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
@@ -1063,10 +1057,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python311/work.m68k/Python-3.11.7 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python311/work/Python-3.11.8 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python311/work.m68k/Python-3.11.7 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python311/work/Python-3.11.8 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -1095,10 +1089,10 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 0,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 1,
+ 'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/tmp/pkgbuild/lang/python311/work.m68k/Python-3.11.7',
- 'abs_srcdir': '/tmp/pkgbuild/lang/python311/work.m68k/Python-3.11.7',
+ 'abs_builddir': '/usr/pkgsrc/lang/python311/work/Python-3.11.8',
+ 'abs_srcdir': '/usr/pkgsrc/lang/python311/work/Python-3.11.8',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
